#[non_exhaustive]pub struct PublicRoomsChunk {
pub canonical_alias: Option<OwnedRoomAliasId>,
pub name: Option<String>,
pub num_joined_members: UInt,
pub room_id: OwnedRoomId,
pub topic: Option<String>,
pub world_readable: bool,
pub guest_can_join: bool,
pub avatar_url: Option<OwnedMxcUri>,
pub join_rule: JoinRuleKind,
pub room_type: Option<RoomType>,
}Expand description
A chunk of a room list response, describing one room.
To create an instance of this type, first create a PublicRoomsChunkInit and convert it via
PublicRoomsChunk::from / .into(). It is also possible to construct this type from or convert
it to a RoomSummary.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.canonical_alias: Option<OwnedRoomAliasId>The canonical alias of the room, if any.
name: Option<String>The name of the room, if any.
num_joined_members: UIntThe number of members joined to the room.
room_id: OwnedRoomIdThe ID of the room.
topic: Option<String>The topic of the room, if any.
world_readable: boolWhether the room may be viewed by guest users without joining.
guest_can_join: boolWhether guest users may join the room and participate in it.
If they can, they will be subject to ordinary power level rules like any other user.
avatar_url: Option<OwnedMxcUri>The URL for the room’s avatar, if one is set.
If you activate the compat-empty-string-null feature, this field being an empty string in
JSON will result in None here during deserialization.
join_rule: JoinRuleKindThe join rule of the room.
room_type: Option<RoomType>The type of room from m.room.create, if any.